pub fn init(config: SparklesConfig) -> FinalizeGuardExpand description
Init sparkles with the provided config
Returns a guard that will finalize global buffer when dropped
Attention
Do not forget to save finalize guard, returned from this call! If you drop it too early, sparkles thread will be finished and no more data will be recorded!